@@ -8,6 +8,6 @@ pub use dir::{Dir, DirEntry};
 pub use makedev::{major, makedev, minor};
 pub use types::{
     Access, Advice, AtFlags, Dev, FallocateFlags, FdFlags, FileType, FlockOperation, FsWord,
-    MemfdFlags, Mode, OFlags, RawMode, RenameFlags, ResolveFlags, Stat, StatFs, Statx, StatxFlags,
-    NFS_SUPER_MAGIC, PROC_SUPER_MAGIC, UTIME_NOW, UTIME_OMIT,
+    MemfdFlags, Mode, OFlags, RawMode, RenameFlags, ResolveFlags, SealFlags, Stat, StatFs, Statx,
+    StatxFlags, StatxTimestamp, NFS_SUPER_MAGIC, PROC_SUPER_MAGIC, UTIME_NOW, UTIME_OMIT,
 };
