@@ -400,8 +400,8 @@ bitflags! {
     /// `F_SEAL_*` constants for use with [`fcntl_add_seals`] and
     /// [`fcntl_get_seals`].
     ///
-    /// [`fcntl_add_seals`]: rustix::fs::fcntl_add_seals
-    /// [`fcntl_get_seals`]: rustix::fs::fcntl_get_seals
+    /// [`fcntl_add_seals`]: crate::fs::fcntl_add_seals
+    /// [`fcntl_get_seals`]: crate::fs::fcntl_get_seals
     pub struct SealFlags: u32 {
        /// `F_SEAL_SEAL`.
        const SEAL = linux_raw_sys::general::F_SEAL_SEAL;
@@ -460,6 +460,9 @@ bitflags! {
         /// `STATX_BTIME`
         const BTIME = linux_raw_sys::general::STATX_BTIME;
 
+        /// `STATX_MNT_ID` (since Linux 5.8)
+        const MNT_ID = linux_raw_sys::general::STATX_MNT_ID;
+
         /// `STATX_ALL`
         const ALL = linux_raw_sys::general::STATX_ALL;
     }
@@ -539,6 +542,9 @@ pub type StatFs = linux_raw_sys::general::statfs64;
 /// [`statx`]: crate::fs::statx
 pub type Statx = linux_raw_sys::general::statx;
 
+/// `struct statx_timestamp` for use with [`Statx`].
+pub type StatxTimestamp = linux_raw_sys::general::statx_timestamp;
+
 /// `mode_t`
 #[cfg(not(any(
     target_arch = "x86",
